Examples
#########

The notebooks in this repo are meant to illustrate what you can do with NeuroKit. It is supposed to reveal how easy it has become to use cutting-edge methods, and still retain the liberty to change a myriad of parameters. These notebooks are organized in different sections that correspond to NeuroKit's modules.

.. toctree::
   :maxdepth: 1
   
   interactive
   simulation
   custom
   eventrelated
   intervalrelated
   eda
   rrv
   edr
   heartbeats
   ecg_delineate
   epochs_create
   hrv
   complexity
   eog
   fit_function

